;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;
; File:		SGITOOLS.LSP
;
; Purpose:	A collection of SGI Tools functions 
;
: To run:	At the AutoCAD Command prompt:
;		(load "sgitools")
;
; IMPORTANT:	This AutoLISP file *MUST* be in you ACAD search path
;		in order for the Bonus Pack AutoCAD menu to function
;		properly, especially the Cut&Paste and File Export
;		sections.
;
; Written by:	Roger Brown, P.E.	- Silicon Graphics
;		Erik Mulder		- Silicon Graphics
;
(setq SGItoolsVersion "3.2")
(prompt (strcat "\nLoading sgiools.lsp version " SGItoolsVersion " ..."))
;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;
; Command:	InventorOut
;
; Function:	Writes an Inventor file of the current drawing.
;
; Creates:	TEMPPREFIX/DWGNAME.dxf and TEMPPREFIX/DWGNAME\
;		The intermediate DXF file is removed after use.
;	
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
(defun C:INVENTOROUT( / basename cmd_str filename echo )
  (setq echo (getvar "CMDECHO"))
  (setvar "CMDECHO" echo)
  ; Strip any leading directory information
  (if (wcmatch (getvar "DWGNAME") (strcat (getvar "DWGPREFIX") "*"))
    (setq basename (substr (getvar "DWGNAME") (1+ (strlen (getvar "DWGPREFIX")))))
    (setq basename (getvar "DWGNAME"))
  )
  ; Determine location of intermediate DXF file
  (if (getvar "TEMPPREFIX")  ; Look for TEMPPREFIX setting
    (setq filename (strcat (getvar "TEMPPREFIX") basename))
    (setq filename (strcat "./" basename))
  )
  ; Create the intermediate DXF file
  (prompt "Processing drawing data...\n")
  (command "_dxfout" filename "_binary")
  ; Create the final Inventor data file
  (setq cmd_str (strcat "dxftoiv.sh -b " filename".dxf >" filename".iv;rm -f "filename".dxf"))
  (prompt "Exporting INVENTOR file...\n")
  (command "_shell" cmd_str)
  (graphscr)
  (setvar "CMDECHO" echo)
  (princ)
)


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;
; Command:	InventorOut2
;
; Function:	 Writes an Inventor/2sided file of the current drawing.
;
; Creates:	TEMPPREFIX/DWGNAME.dxf and TEMPPREFIX/DWGNAME.iv
;		The intermediate DXF file is removed after use.
;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
(defun C:INVENTOROUT2( / basename cmd_str filename echo )
  (setq echo (getvar "CMDECHO"))
  (setvar "CMDECHO" 0)
  ; Strip any leading directory information
  (if (wcmatch (getvar "DWGNAME") (strcat (getvar "DWGPREFIX") "*"))
    (setq basename (substr (getvar "DWGNAME") (1+ (strlen (getvar "DWGPREFIX")))))
    (setq basename (getvar "DWGNAME"))
  )
  ; Determine location of intermediate DXF file
  (if (getvar "TEMPPREFIX")  ; Look for TEMPPREFIX setting
    (setq filename (strcat (getvar "TEMPPREFIX") basename))
    (setq filename (strcat "./" basename))
  )
  ; Create the intermediate DXF file
  (prompt "Processing drawing data...\n")
  (command "_dxfout" filename "_binary")
  ; Create the final Inventor data file
  (setq cmd_str (strcat "dxftoiv.sh -b " filename".dxf | ivtwoside.sh >" filename".iv;rm -f "filename".dxf"))
  (prompt "Exporting 2-sided INVENTOR file...\n")
  (command "_shell" cmd_str)
  (graphscr)
  (setvar "CMDECHO" echo)
  (princ)
)


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;
; Command:	IvView
;
; Function:	Writes out an IV file of the current drawing 
;		and starts the Inventor Viewer tool.
;
; Creates:	TEMPPREFIX/DWGNAME.dxf and TEMPPREFIX/DWGNAME.iv
;		The intermediate DXF file is removed after use.
;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
(defun C:IVVIEW( / basename cmd_str fil filename echo )
  (setq echo (getvar "CMDECHO"))
  (setvar "CMDECHO" 0)
  ; Strip any leading directory information
  (if (wcmatch (getvar "DWGNAME") (strcat (getvar "DWGPREFIX") "*"))
    (setq basename (substr (getvar "DWGNAME") (1+ (strlen (getvar "DWGPREFIX")))))
    (setq basename (getvar "DWGNAME"))
  )
  ; Determine location of intermediate DXF file
  (if (getvar "TEMPPREFIX")  ; Look for TEMPPREFIX setting
    (setq filename (strcat (getvar "TEMPPREFIX") basename))
    (setq filename (strcat "./" basename))
  )
  ; Create the intermediate DXF file
  (prompt "Processing drawing data...\n")
  (command "_dxfout" filename "_binary")
  ; Create the final Inventor data file
  (setq cmd_str (strcat "dxftoiv.sh -b " filename".dxf >" filename".iv;rm -f "filename".dxf"))
  (prompt "Writing Inventor data...\n")
  (command "_shell" cmd_str)
  ; Start the Inventor file viewer
  (setq fil (findfile "ivview.sh"))
  (if fil
    (setq cmd_str (strcat fil " " filename".iv"))
    (setq cmd_str (strcat "SceneViewer " filename".iv &"))
  )
  (prompt "Starting Inventor viewer...\n")
  (command "_shell" cmd_str)
  (graphscr)
  (setvar "CMDECHO" echo)
  (princ)
)


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;
; Command:	GView
;
; Function:	Writes out an IV file of the current drawing 
;		and starts the Inventor Graph Editor tool.
;
; Creates:	TEMPPREFIX/DWGNAME.dxf and TEMPPREFIX/DWGNAME.iv
;		The intermediate DXF file is removed after use.
;	
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
(defun C:GVIEW( / basename cmd_str fil filename echo )
  (setq echo (getvar "CMDECHO"))
  (setvar "CMDECHO" 0)
  ; Strip any leading directory information
  (if (wcmatch (getvar "DWGNAME") (strcat (getvar "DWGPREFIX") "*"))
    (setq basename (substr (getvar "DWGNAME") (1+ (strlen (getvar "DWGPREFIX")))))
    (setq basename (getvar "DWGNAME"))
  )
  ; Determine location of intermediate DXF file
  (if (getvar "TEMPPREFIX")  ; Look for TEMPPREFIX setting
    (setq filename (strcat (getvar "TEMPPREFIX") basename))
    (setq filename (strcat "./" basename))
  )
  ; Create the intermediate DXF file
  (prompt "Processing drawing data...\n")
  (command "_dxfout" filename "_binary")
  ; Create the final Inventor data file
  (setq cmd_str (strcat "dxftoiv.sh -b " filename".dxf >" filename".iv;rm -f "filename".dxf"))
  (prompt "Writing Inventor data...\n")
  (command "_shell" cmd_str)
  ; Start the Inventor graph editor
  (setq fil (findfile "ivgraph.sh"))
  (if fil
    (setq cmd_str (strcat fil " " filename".iv"))
    (setq cmd_str (strcat "SceneViewer " filename".iv &"))
  )
  (prompt "Starting Inventor graph editor...\n")
  (command "_shell" cmd_str)
  (graphscr)
  (setvar "CMDECHO" echo)
  (princ)
)


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;
; Command:	SceneViewer
;
; Function:	Writes out an IV file of the current drawing 
;		and starts the Inventor Editor tool.
;
; Creates:	TEMPPREFIX/DWGNAME.dxf and TEMPPREFIX/DWGNAME.iv
;		The intermediate DXF file is removed after use.
;	
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
(defun C:SCENEVIEWER( / basename cmd_str fil filename echo )
  (setq echo (getvar "CMDECHO"))
  (setvar "CMDECHO" 0)
  ; Strip any leading directory information
  (if (wcmatch (getvar "DWGNAME") (strcat (getvar "DWGPREFIX") "*"))
    (setq basename (substr (getvar "DWGNAME") (1+ (strlen (getvar "DWGPREFIX")))))
    (setq basename (getvar "DWGNAME"))
  )
  ; Determine location of intermediate DXF file
  (if (getvar "TEMPPREFIX")  ; Look for TEMPPREFIX setting
    (setq filename (strcat (getvar "TEMPPREFIX") basename))
    (setq filename (strcat "./" basename))
  )
  ; Create the intermediate DXF file
  (prompt "Processing drawing data...\n")
  (command "_dxfout" filename "_binary")
  ; Create the final Inventor data file
  (setq cmd_str (strcat "dxftoiv.sh -b " filename".dxf >" filename".iv;rm -f "filename".dxf"))
  (prompt "Writing Inventor data...\n")
  (command "_shell" cmd_str)
  ; Start the Inventor file editor
  (setq fil (findfile "ivedit.sh"))
  (if fil
    (setq cmd_str (strcat fil " " filename".iv"))
    (setq cmd_str (strcat "SceneViewer " filename".iv &"))
  )
  (prompt "Starting Inventor editor...\n")
  (command "_shell" cmd_str)
  (graphscr)
  (setvar "CMDECHO" echo)
  (princ)
)


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;
; Command:	Annotator
;
; Function:	Writes out an IV file of the current drawing 
;		and starts the Annotator program.
;
; Creates:	TEMPPREFIX/DWGNAME.dxf and TEMPPREFIX/DWGNAME.ia
;		The intermediate DXF file is removed after use.
;	
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
(defun C:ANNOTATOR( / basename cmd_str filename echo )
  (setq echo (getvar "CMDECHO"))
  (setvar "CMDECHO" 0)
  ; Strip any leading directory information
  (if (wcmatch (getvar "DWGNAME") (strcat (getvar "DWGPREFIX") "*"))
    (setq basename (substr (getvar "DWGNAME") (1+ (strlen (getvar "DWGPREFIX")))))
    (setq basename (getvar "DWGNAME"))
  )
  ; Determine location of intermediate DXF file
  (if (getvar "TEMPPREFIX")  ; Look for TEMPPREFIX setting
    (setq filename (strcat (getvar "TEMPPREFIX") basename))
    (setq filename (strcat "./" basename))
  )
  ; Create the intermediate DXF file
  (prompt "Processing drawing data...\n")
  (command "_dxfout" filename "_binary")
  ; Create the final Inventor data file
  (setq cmd_str (strcat "dxftoiv.sh -b " filename".dxf >" filename".ia;rm -f "filename".dxf"))
  (prompt "Writing Inventor data...\n")
  (command "_shell" cmd_str)
  ; Start Annotator
  (setq fil (findfile "annot.sh"))
  (if fil
    (setq cmd_str (strcat fil " " filename".ia"))
    (setq cmd_str (strcat "SceneViewer " filename".ia &"))
  )
  (prompt "Starting Annotator...\n")
  (command "_shell" cmd_str)
  (graphscr)
  (setvar "CMDECHO" echo)
  (princ)
)


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;
; Command:	IrisView_II
;
; Function:	Writes out a DXF file of the current drawing and 
;		starts the Irisview_II viewer.
;
; Creates:	TEMPPREFIX/DWGNAME.dxf
;	
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
(defun C:IRISVIEW_II( / basename cmd_str filename texture echo )
  (setq echo (getvar "CMDECHO"))
  (setvar "CMDECHO" 0)
  ; Strip any leading directory information
  (if (wcmatch (getvar "DWGNAME") (strcat (getvar "DWGPREFIX") "*"))
    (setq basename (substr (getvar "DWGNAME") (1+ (strlen (getvar "DWGPREFIX")))))
    (setq basename (getvar "DWGNAME"))
  )
  ; Determine location of intermediate DXF file
  (if (getvar "TEMPPREFIX")  ; Look for TEMPPREFIX setting
    (setq filename (strcat (getvar "TEMPPREFIX") basename))
    (setq filename (strcat "./" basename))
  )
  ; Create the intermediate DXF file
  (prompt "Processing drawing data...\n")
  (command "_dxfout" filename "_binary")
  (setq texture (strcat " -texture " (getenv "IVII_T")))
  (setq cmd_str (strcat "irisview_II -f " filename ".dxf" texture " &"))
  (prompt "Starting IRISVIEW_II...\n")
  (command "_shell" cmd_str)
  (graphscr)
  (setvar "CMDECHO" echo)
  (princ)
)


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;
; Command:	SGI_CUT
;
; Function:	Writes (WBLOCK) selected items to temporary file.
;
; Creates:	$TMP/dwgtemp.dwg
;	
; Note:		Items removed from the current drawing (in the BLOCK)
;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
(defun C:SGI_CUT( / filename entities insertion echo )
  (setq echo (getvar "CMDECHO"))
  (setvar "CMDECHO" 0)
  (if (getenv "TMP")    ; Look for $TMP setting
    (setq filename (strcat (getenv "TMP") "/dwgtemp.dwg"))
    (setq filename "./dwgtemp.dwg")
  )
  (prompt "Select objects to cut: ")
  (setq entities (ssget))
  (prompt "Select point for later insertion:\n")
  (setq insertion (getpoint))
  (if (findfile filename)
    (command "_wblock" filename "_yes" "" insertion entities "")
    (command "_wblock" filename "" insertion entities "")
  )
  (setq entities nil)
  (prin1)
)


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;
; Command:	SGI_COPY
;
; Function:	Writes (WBLOCK) selected items to temporary file.
;
; Creates:	$TMP/dwgtemp.dwg
;	
; Note:		Items remain in the current drawing
;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
(defun C:SGI_COPY( / filename echo entities insertion echo )
  (setq echo (getvar "CMDECHO"))
  (setvar "CMDECHO" 0)
  (if (getenv "TMP")    ; Look for $TMP setting
    (setq filename (strcat (getenv "TMP") "/dwgtemp.dwg"))
    (setq filename "./dwgtemp.dwg")
  )
  (prompt "Select objects to copy: ")
  (setq entities (ssget))
  (prompt "Select point for later insertion:\n")
  (setq insertion (getpoint))
  (if (findfile filename)
    (command "_wblock" filename "_yes" "" insertion entities "")
    (command "_wblock" filename "" insertion entities "")
  )
  (command "oops")
  (setq insertion  nil)
  (setvar "CMDECHO" echo)
  (prin1)
)


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;
; Command:	SGI_PASTE
;
; Function:	Reads (INSERT) items from temporary file into
;		current drawing.
;
; Uses:		Reads $TMP/dwgtemp.dwg
;	
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
(defun C:SGI_PASTE( / filename ins_blk echo )
  (setq echo (getvar "CMDECHO"))
  (setvar "CMDECHO" 0)
  (if (getenv "TMP")    ; Look for $TMP setting
    (setq filename (strcat (getenv "TMP") "/dwgtemp.dwg"))
    (setq filename "./dwgtemp.dwg")
  )
  (if (findfile filename)
    (progn
      (prompt "Select insertion point:\n")
      (setq ins_blk (strcat "*" filename))
      (command "_insert" ins_blk pause "" "")
    )
    (prompt "\nNothing to paste: ")
  )
  (setvar "CMDECHO" echo)
  (prin1)
)


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;
; Command:	SGI_CLEAR
;
; Function:	Clears out the temporary file.
;
; Uses:		Deletes $TMP/dwgtemp.dwg
;	
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
(defun C:SGI_CLEAR( / filename echo )
  (setq echo (getvar "CMDECHO"))
  (setvar "CMDECHO" 0)
  (if (getenv "TMP")    ; Look for $TMP setting
    (setq filename (strcat (getenv "TMP") "/dwgtemp.dwg"))
    (setq filename "./dwgtemp.dwg")
  )
  (if (findfile filename)
    (command "_del" filename)
  )
  (setvar "CMDECHO" echo)
  (prin1)
)

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;
; Command:	SGI_IVcopy
;
; Function:	Writes selected items to Inventor file for subsequent
;		insertion into other Inventor-capable applications,
;		e.g. Showcase.  Items remain in the current drawing
;
; Creates:	TEMPPREFIX/DWGNAME.dxf and TEMPPREFIX/DWGNAME.iv
;		The intermediate DXF file is removed after use.
;	
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
(defun C:SGI_IVCOPY( / basename cmd_str filename entities echo dialog )
  (setq echo (getvar "CMDECHO"))
  (setq dialog (getvar "FILEDIA"))
  (setvar "CMDECHO" 0)
  ; Strip any leading directory information
  (if (wcmatch (getvar "DWGNAME") (strcat (getvar "DWGPREFIX") "*"))
    (setq basename (substr (getvar "DWGNAME") (1+ (strlen (getvar "DWGPREFIX")))))
    (setq basename (getvar "DWGNAME"))
  )
  ; Determine location of intermediate DXF file
  (if (getvar "TEMPPREFIX")  ; Look for TEMPPREFIX setting
    (setq filename (strcat (getvar "TEMPPREFIX") basename))
    (setq filename (strcat "./" basename))
  )
  ; Create the intermediate DXF file
  (prompt "Select entities to export...\n")
  (setq entities (ssget))
  (prompt "Processing drawing data...\n")
  (command "_dxfout" filename "_entities" entities "" "_binary")
  ; Create the final Inventor data file
  (setq cmd_str (strcat "dxftoiv.sh -b " filename".dxf >" filename".iv;rm -f "filename".dxf"))
  (prompt "Exporting INVENTOR Copy file...\n")
  (command "_shell" cmd_str)
  (graphscr)
  (setq entities nil)
  (setvar "FILEDIA" dialog)
  (setvar "CMDECHO" echo)
  (princ)
)


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;
; Command:	IrisView (obsolete)
;
; Function:	Writes out a DXF file of the current drawing and 
;		starts the Irisview viewer.
;
; Creates:	TEMPPREFIX/DWGNAME.dxf
;	
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
(defun C:IRISVIEW( / basename cmd_str filename echo )
  (setq echo (getvar "CMDECHO"))
  (setvar "CMDECHO" 0)
  ; Strip any leading directory information
  (if (wcmatch (getvar "DWGNAME") (strcat (getvar "DWGPREFIX") "*"))
    (setq basename (substr (getvar "DWGNAME") (1+ (strlen (getvar "DWGPREFIX")))))
    (setq basename (getvar "DWGNAME"))
  )
  ; Determine location of intermediate DXF file
  (if (getvar "TEMPPREFIX")  ; Look for TEMPPREFIX setting
    (setq filename (strcat (getvar "TEMPPREFIX") basename))
    (setq filename (strcat "./" basename))
  )
  ; Create the intermediate DXF file
  (prompt "Processing drawing data...\n")
  (command "_dxfout" filename "_binary")
  (setq cmd_str (strcat "irisview -f " filename ".dxf &"))
  (prompt "Starting IRISVIEW...\n")
  (command "_shell" cmd_str)
  (graphscr)
  (prompt "OK.")
  (setvar "CMDECHO" echo)
  (princ)
)


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;
; Command:	ExaminerViewer - (obsolete - requires dxf.to.iv)
;
; Function:	Writes out a DXF file of the current drawing and 
;		starts the Inventor ExaminerViewer.
;
; Creates:	TEMPPREFIX/DWGNAME.dxf
;	
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
(defun C:EXAMINERVIEWER( / basename cmd_str filename echo )
  (setq echo (getvar "CMDECHO"))
  (setvar "CMDECHO" 0)
  ; Strip any leading directory information
  (if (wcmatch (getvar "DWGNAME") (strcat (getvar "DWGPREFIX") "*"))
    (setq basename (substr (getvar "DWGNAME") (1+ (strlen (getvar "DWGPREFIX")))))
    (setq basename (getvar "DWGNAME"))
  )
  ; Determine location of intermediate DXF file
  (if (getvar "TEMPPREFIX")  ; Look for TEMPPREFIX setting
    (setq filename (strcat (getvar "TEMPPREFIX") basename))
    (setq filename (strcat "./" basename))
  )
  ; Create the intermediate DXF file
  (prompt "Processing drawing data...\n")
  (command "_dxfout" filename "_binary")
  (prompt "Starting EXAMINER VIEWER...")
  (setq cmd_str (strcat "dxf.to.iv " filename ".dxf &"))
  (command "_shell" cmd_str)
  (graphscr)
  (prompt "OK.")
  (setvar "CMDECHO" echo)
  (princ)
)


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;
; Command:	SGO_Out - (obsolete - requires dxf.to.sgo)
;
; Function:	Writes out a SGO(Showcase2) file of the current drawing.
;
; Creates:	TEMPPREFIX/DWGNAME.dxf and TEMPPREFIX/DWGNAME.sgo
;	
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
(defun C:SGO_OUT( / basename cmd_str filename echo )
  (setq echo (getvar "CMDECHO"))
  (setvar "CMDECHO" 0)
  ; Strip any leading directory information
  (if (wcmatch (getvar "DWGNAME") (strcat (getvar "DWGPREFIX") "*"))
    (setq basename (substr (getvar "DWGNAME") (1+ (strlen (getvar "DWGPREFIX")))))
    (setq basename (getvar "DWGNAME"))
  )
  ; Determine location of intermediate DXF file
  (if (getvar "TEMPPREFIX")  ; Look for TEMPPREFIX setting
    (setq filename (strcat (getvar "TEMPPREFIX") basename))
    (setq filename (strcat "./" basename))
  )
  ; Create the intermediate DXF file
  (prompt "Processing drawing data...\n")
  (command "_dxfout" filename "_binary")
  (setq cmd_str (strcat "dxf.to.sgo " filename ".dxf " (getvar "DWGNAME") ".sgo"))
  (prompt "Exporting SGO file...")
  (command "_shell" cmd_str)
  (graphscr)
  (prompt "OK.")
  (setvar "CMDECHO" echo)
  (princ)
)


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;
; Command:	SGI_SENDFAX
;
; Function:	An AutoCAD interface to the FlexFAX software.
;
; Creates:	TEMPPREFIX/sendfax.eps (deleted after sending)
;	
; Notes:	1) Requires installation of FlexFAX software package.
;			See: BonusPack/bin/Communication/FlexFAX
;		2) Uses $FAXSERVER (or localhost) for FAX server.
;		3) Requires installation of PostScript utilities.
;			See: BonusPack/bin/ImageTools/psutils.
;		4) You will receive an automatically generated e-mail 
;		   message upon completion of the FAX transfer.  In
;		   addition, if the initial transmission is not 
;		   completed (e.g. busy), you will receive an e-mail
;		   every time the job is re-queded for re-transmission.
;
; Written by:	Roger Brown P.E. - 04.NOV.94 - Silicon Graphics, Inc.
;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
(defun c:SGI_SENDFAX ( / dcl_id rslt from use_user to co loc re cmt fax srv use_srv res cmd tmp view pauses fname echo )
  (setq echo (getvar "CMDECHO"))
  (setvar "CMDECHO" echo)
  (setq dcl_id (load_dialog "sgitools"))
  (if (not (new_dialog "sgi_sendfax" dcl_id))
    (exit)
    (progn
      ;;
      ;; If SGI_USE_FAXSERVER is toggled on, disable SGI_FAXSERVER edit box and vice versa.
      ;;
      (defun do_faxserver()
        (mode_tile "SGI_FAXSERVER" (setq use_srv (atoi (get_tile "SGI_USE_FAXSERVER"))))
	; Debug
	;(print use_srv)
      )
      ;;
      ;; If SGI_USE_USER is toggled on, disable SGI_FAX_FROM edit box and vice versa.
      ;;
      (defun do_user()
        (mode_tile "SGI_FAX_FROM" (setq use_user (atoi (get_tile "SGI_USE_USER"))))
	; Debug
	;(print use_user)
      )
      ;;
      ;; Callback for FAX resolution selection.
      ;;
      (defun do_resolution (which)
        (cond
	  ((= which "SGI_FAX_MEDIUM_RES") (setq res (strcat " -m")))
	  ((= which "SGI_FAX_LOW_RES")    (setq res (strcat " -l")))
	)
	; Debug
	;(print res)
      )
      ;;
      ;; Help message
      ;;
      (defun do_help ()
        (if (not (acad_helpdlg "gldriver" "SENDFAX"))
	  (princ "Help file [gldriver.hlp] not found")
	)
      )
      ;;
      ;; Callback for FAX view selection.
      ;;
      (defun do_view (which)
        (cond
	  ((= which "SGI_FAX_DISPLAY")	(setq view (strcat "_DISPLAY")	pauses 0))
	  ((= which "SGI_FAX_EXTENTS")	(setq view (strcat "_EXTENTS")	pauses 0))
	  ((= which "SGI_FAX_LIMITS")	(setq view (strcat "_LIMITS")	pauses 0))
	  ((= which "SGI_FAX_VIEW")	(setq view (strcat "_VIEW")	pauses 1))
	  ((= which "SGI_FAX_WINDOW")	(setq view (strcat "_WINDOW")	pauses 2))
	)
	; Debug
	;(print view)
	;(print pauses)
      )
      ;;
      ;; Initialize local variable to default values
      ;;
      (setq to		(strcat ""))
      (setq fax		(strcat "+1-"))
      (setq co		(strcat ""))
      (setq loc		(strcat ""))
      (setq re		(getvar "DWGNAME"))
      (setq cmt		(strcat ""))
      (setq from	(getenv "USER"))
      (if (getenv "FAXSERVER")  ; Look for $FAXSERVER setting
        (setq srv (getenv "FAXSERVER"))
        (setq srv (strcat "localhost"))
      )
      (setq res (strcat ""))
      (setq view (strcat "_DISPLAY"))
      (setq pauses 0)
      ;
      ; Determine location of intermediate EPS file
      ;
      (if (getvar "TEMPPREFIX")  ; Look for TEMPPREFIX setting
        (setq fname (strcat (getvar "TEMPPREFIX") "sendfax"))
	(setq fname (strcat "./sendfax"))
      )
      ;
      ; Initialize the default tiles
      ;
      (set_tile "SGI_FAX_REGARD"      re)
      (set_tile "SGI_FAX_NUMBER"      fax)
      ;
      (set_tile  "SGI_FAX_FROM"       from)
      (mode_tile "SGI_FAX_FROM"       1)
      (set_tile  "SGI_USE_USER"      "0")
      ;
      (set_tile  "SGI_FAXSERVER"      srv)
      (mode_tile "SGI_FAXSERVER"      1)
      (set_tile  "SGI_USE_FAXSERVER" "0")
      ;
      ; Set up callbacks
      ;
      (action_tile "SGI_FAX_TO"		"(setq to   $value)")
      (action_tile "SGI_FAX_NUMBER"	"(setq fax  $value)")
      (action_tile "SGI_FAX_COMPANY"	"(setq co   $value)")
      (action_tile "SGI_FAX_LOCATION"	"(setq loc  $value)")
      (action_tile "SGI_FAX_REGARD"	"(setq re   $value)")
      (action_tile "SGI_FAX_COMMENT"	"(setq cmt  $value)")
      ;
      (action_tile "SGI_FAX_FROM"	"(setq from $value)")
      (action_tile "SGI_USE_USER"	"(do_user)")
      ;
      (action_tile "SGI_FAXSERVER"	"(setq srv  $value)")
      (action_tile "SGI_USE_FAXSERVER"	"(do_faxserver)")
      ;
      (action_tile "SGI_FAX_LOW_RES"	"(do_resolution $key)")
      (action_tile "SGI_FAX_MEDIUM_RES"	"(do_resolution $key)")
      ;
      (action_tile "SGI_FAX_DISPLAY"	"(do_view $key)")
      (action_tile "SGI_FAX_EXTENTS"	"(do_view $key)")
      (action_tile "SGI_FAX_LIMITS"	"(do_view $key)")
      (action_tile "SGI_FAX_VIEW"	"(do_view $key)")
      (action_tile "SGI_FAX_WINDOW"	"(do_view $key)")
      ;
      (action_tile "accept"		"(done_dialog 1)")
      (action_tile "help"		"(do_help)")
      ;
      ; Fire off the dialog
      ;
      (setq rslt (start_dialog))
      (cond
        ((= rslt 1)
          (setq tmp (strcat ""))
          (if (> (strlen co)   1) (setq tmp (strcat tmp " -x \"" co "\"")))
          (if (> (strlen loc)  1) (setq tmp (strcat tmp " -y \"" loc "\"")))
          (if (> (strlen re)   1) (setq tmp (strcat tmp " -r \"" re "\"")))
          (if (> (strlen cmt)  1) (setq tmp (strcat tmp " -c \"" cmt "\"")))
          (if (> (strlen res)  1) (setq tmp (strcat tmp res)))
          (if (= use_user 0)
	    (if (> (strlen from) 1) (setq tmp (strcat tmp " -f \"" from "\"")))
	  )
          (if (= use_srv 0)
	    (if (> (strlen srv)  1) (setq tmp (strcat tmp " -h " srv)))
	  )
	  ;
	  ; Write the EPS file
	  ;
          (cond
	    ((= pauses 0) (command "_psout" fname view "_NONE" "" "_FIT" ""))
	    ((= pauses 1) (command "_psout" fname view pause "_NONE" "" "_FIT" ""))
	    ((= pauses 2) (command "_psout" fname view pause pause "_NONE" "" "_FIT" ""))
	  )
	  ;
	  ; Construct O/S command to best fit EPS file to FAX page
	  ;
          (setq cmd (strcat "epsffit -c -m 20 20 592 772 " fname ".eps " fname "p.eps"))
          (command "_shell" cmd)
	  ;
	  ; Construct O/S command to send FAX via FlexFAX
	  ;
          (setq cmd (strcat "sendfax -DR " tmp " -d \""to"@"fax"\" " fname "p.eps"))
          (command "_shell" cmd)
	  ; Debug
	  ;(print cmd)
	  ;
	  ; Clean up temporary file(s)
	  ;
          (setq tmp (strcat fname ".eps"))
          (command "_del" tmp)
          (setq tmp (strcat fname "p.eps"))
          (command "_del" tmp)
        )
      )
    )
  )
  (unload_dialog dcl_id)
  (setvar "CMDECHO" echo)
  (princ)
)


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;
; Command:	SGI_HELP
;
; Function:	Invokes an SGI help dialog box.
;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
(defun C:SGI_HELP( / echo)
  (setq echo (getvar "CMDECHO"))
  (setvar "CMDECHO" 0)
  (if (not (acad_helpdlg "gldriver" "GLDRIVER"))
    (princ "Help file [gldriver.hlp] not found"))
  (setvar "CMDECHO" echo)
  (princ)
)


(prompt "OK.")
(princ)
