;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;
; File:		TIMER.LSP
;
; Purpose:	A collection of display list timing functions.
;
: To run:	At the AutoCAD Command prompt:
;		(load "timer")
;
; Written by:	Roger Brown, P.E.
;
; Note:		This file may modify the following AutoCAD varibles:
;			CMDECHO
;			SHADEDGE
;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;
; Command:	SGI_TRTDVIEW
;
; Function:	Start timer,
;		issue RTDVIEW,
;		stop timer,
;		diplay elapsed time.
;
; Notes:	Should set the desired RMODE_xxx before running.
;		Only works with GL display driver
;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
(defun C:SGI_TRTDVIEW ()
	(setvar "CMDECHO" 0)
	(command "_time" "_reset" "_on" "")
	(command "c:rtdview")
	(command "_time" "_off" "_display" "")
	(setvar "CMDECHO" 1)
)


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;
; Command:	SGI_TSOLMESH
;
; Function:	Start timer,
;		issue SOLMESH,
;		stop timer,
;		diplay elapsed time.
;
; Note:		Requires AME license (and AME xload'ed).
;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
(defun C:SGI_TSOLMESH ()
	(setvar "CMDECHO" 0)
	(command "_time" "_reset" "_on" "")
	(solmesh (ssget "X"))
	(command "_time" "_off" "_display" "")
	(setvar "CMDECHO" 1)
)


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;
; Command:	SGI_TOPEN
;
; Function:	Start timer,
;		issue OPEN,
;		stop timer,
;		diplay elapsed time.
;
; Note:		You'll be prompted for the drawing name to open.
;		Since AutoLISP is re-loaded after opening a
;		new drawing, the elapsed time will not be 
;		displayed, rather a time before and after the open
;		The difference is the drawing open time.
;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
(defun C:SGI_TOPEN ( / fname)
	(setq fname (getstring "Enter name of drawing to OPEN: "))
	(setvar "CMDECHO" 0)
	(command "_time" "_display" "")
	(command "_open" fname "")
	(command "_time" "_display" "")
	(setvar "CMDECHO" 1)
)


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;
; Command:	SGI_TPAPERSPACE
;
; Function:	Start timer,
;		issue 1 TILEMODE 0,
;		stop timer,
;		diplay elapsed time.
;		Only valid when going from 1 -> 0
;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
(defun C:SGI_TPAPERSPACE ()
	(setvar "CMDECHO" 0)
	(command "_time" "_reset" "_on" "")
	(setvar "TILEMODE" 0)
	(command "_time" "_off" "_display" "")
	(setvar "CMDECHO" 1)
)


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;
; Command:	SGI_TMODELSPACE
;
; Function:	Start timer,
;		issue 1 TILEMODE 1,
;		stop timer,
;		diplay elapsed time.
;		Only valid when going from 0 -> 1
;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
(defun C:SGI_TMODELSPACE ()
	(setvar "CMDECHO" 0)
	(command "_time" "_reset" "_on" "")
	(setvar "TILEMODE" 1)
	(command "_time" "_off" "_display" "")
	(setvar "CMDECHO" 1)
)


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;
; Command:	SGI_TZOOM
;
; Function:	Start timer,
;		issue ZOOM 1-10,
;		stop timer,
;		diplay elapsed time.
;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
(defun C:SGI_TZOOM ()
	(setvar "CMDECHO" 0)
	(command "_time" "_reset" "_on" "")
	(command "_zoom"  "1" "")
	(command "_zoom"  "2" "")
	(command "_zoom"  "3" "")
	(command "_zoom"  "4" "")
	(command "_zoom"  "5" "")
	(command "_zoom"  "6" "")
	(command "_zoom"  "7" "")
	(command "_zoom"  "8" "")
	(command "_zoom"  "9" "")
	(command "_zoom" "10" "")
	(command "_time" "_off" "_display" "")
	(setvar "CMDECHO" 1)
)


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;
; Command:	SGI_TSHADE
;
; Function:	Start timer,
;		set SHADEDGE to 256-Color mode,
;		issue SHADE,
;		stop timer,
;		diplay elapsed time.
;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
(defun C:SGI_TSHADE ()
	(setvar "CMDECHO" 0)
	(setvar "SHADEDGE" 0)
	(command "_time" "_reset" "_on" "")
	(command "_shade")
	(command "_time" "_off" "_display" "")
	(setvar "CMDECHO" 1)
)


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;
; Command:	SGI_TQHIDE	(Quick HIDE)
;
; Function:	Start timer,
;		set SHADEDGE to Hidden-line mode,
;		issue SHADE,
;		stop timer,
;		diplay elapsed time.
;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
(defun C:SGI_TQHIDE ()
	(setvar "CMDECHO" 0)
	(setvar "SHADEDGE" 2)
	(command "_time" "_reset" "_on" "")
	(command "_shade")
	(command "_time" "_off" "_display" "")
	(setvar "CMDECHO" 1)
)


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;
; Command:	SGI_THIDE
;
; Function:	Start timer,
;		issue HIDE,
;		stop timer,
;		diplay elapsed time.
;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
(defun C:SGI_THIDE ()
	(setvar "CMDECHO" 0)
	(command "_time" "_reset" "_on" "")
	(command "_hide")
	(command "_time" "_off" "_display" "")
	(setvar "CMDECHO" 1)
)


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;
; Command:	SGI_TRENDER
;
; Function:	Start timer,
;		issue RENDER,
;		stop timer,
;		diplay elapsed time.
;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
(defun C:SGI_TRENDER ()
	(setvar "CMDECHO" 0)
	(command "_time" "_reset" "_on" "")
	(c:render)
	(command "_time" "_off" "_display" "")
	(setvar "CMDECHO" 1)
)


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;
; Command:	SGI_TERASE
;
; Function:	Start timer,
;		issue ERASE P,
;		stop timer,
;		diplay elapsed time.
;
; Note:		You should first select something to erase so
;		there is a previous selection set.
;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
(defun C:SGI_TERASE ()
	(setvar "CMDECHO" 0)
	(command "_time" "_reset" "_on" "")
	(command "_erase" "_previous" "")
	(command "_time" "_off" "_display" "")
	(setvar "CMDECHO" 1)
)


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;
; Command:	SGI_TINSERT
;
; Function:	Start timer,
;		issue INSERT fname 0,0 1 1 0.0,
;		stop timer,
;		diplay elapsed time.
;
; Note:		You'll be prompted for the drawing name to insert.
;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
(defun C:SGI_TINSERT ( / fname)
	(setq fname (getstring "Enter name of drawing to INSERT: "))
	(setvar "CMDECHO" 0)
	(command "_time" "_reset" "_on" "")
	(command "_insert" fname "0,0" "1" "" "0")
	(command "_time" "_off" "_display" "")
	(setvar "CMDECHO" 1)
)


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;
; Command:	SGI_TREGENALL
;
; Function:	Start timer,
;		issue 1 REGENALL,
;		stop timer,
;		diplay elapsed time.
;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
(defun C:SGI_TREGENALL ()
	(setvar "CMDECHO" 0)
	(command "_time" "_reset" "_on" "")
	(command "_regenall")
	(command "_time" "_off" "_display" "")
	(setvar "CMDECHO" 1)
)


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;
; Command:	SGI_TREGEN
;
; Function:	Start timer,
;		issue 1 REGEN,
;		stop timer,
;		diplay elapsed time.
;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
(defun C:SGI_TREGEN ()
	(setvar "CMDECHO" 0)
	(command "_time" "_reset" "_on" "")
	(command "_regen")
	(command "_time" "_off" "_display" "")
	(setvar "CMDECHO" 1)
)


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;
; Command:	SGI_TREDRAWALL
;
; Function:	Start timer,
;		issue 1 REDRAWALL's,
;		stop timer,
;		display elapsed time.
;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
(defun C:SGI_TIME_REDRAWALL ()
	(setvar "CMDECHO" 0)
	(command "_time" "_reset" "_on" "")
	(command "_redrawall")
	(command "_time" "_off" "_display" "")
	(setvar "CMDECHO" 1)
)


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;
; Command:	SGI_TREDRAW
;
; Function:	Start timer,
;		issue 10 REDRAW's,
;		stop timer,
;		display elapsed time.
;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
(defun C:SGI_TREDRAW ()
	(setvar "CMDECHO" 0)
	(command "_time" "_reset" "_on" "")
	(command "_redraw")
	(command "_redraw")
	(command "_redraw")
	(command "_redraw")
	(command "_redraw")
	(command "_redraw")
	(command "_redraw")
	(command "_redraw")
	(command "_redraw")
	(command "_redraw")
	(command "_time" "_off" "_display" "")
	(setvar "CMDECHO" 1)
)


